current_gap_end

Function current_gap_end 

pub async fn current_gap_end(
    conn: &mut PgConnection,
) -> ModelResult<Option<DateTime<Utc>>>
When the gap we are in ends, or None outside it. Read off the database’s clock and time zone data, which knows when Finland changes to and from summer time.